using System;
using System.IO;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
using Microsoft.Xna.Framework.Content;

namespace XNACS1Lib
{
    /// <summary>
    /// A circle primitive.
    /// </summary>
    public class XNACS1Circle : XNACS1Primitive
    {

        /// <summary>
        /// Contstructs a circle.
        /// </summary>
        /// <param name="center">center of the circle.</param>
        /// <param name="radius">radius of the circle.</param>
        /// <param name="tex">texture to be used for the circle.</param>
        public XNACS1Circle(Vector2 center, float radius, String tex)
            :
            base(PrimitiveType.PrimitiveCircle, center, new Vector2(2.0f * radius, 2.0f * radius), tex)
        {
        }

        /// <summary>
        /// Constructs a circle.
        /// </summary>
        /// <param name="center">center of the circle.</param>
        /// <param name="radius">radius of the circle.</param>
        public XNACS1Circle(Vector2 center, float radius)
            :
            base(PrimitiveType.PrimitiveCircle, center, new Vector2(2.0f*radius, 2.0f*radius), null)
        {
        }

        /// <summary>
        /// Constructs a circle, with center located at (0,0), and radius of 1.0.
        /// </summary>
        public XNACS1Circle()
            : base(PrimitiveType.PrimitiveCircle)
        { }

        /// <summary>
        /// Radius of the circle.
        /// </summary>
        public float Radius {
            get { return SizeX * 0.5f; }
            set { SizeX = 2.0f* value; SizeY = 2.0f*value; }
        }
    
        /// <summary>
        /// Draws the circle.
        /// </summary>
        protected override void DrawPrimitive() {
            sm_DrawHelper.DrawCircle(m_Center, Radius, m_Rotate, m_Color, m_Texture);
        }
    }
}